@@ -23,7 +23,7 @@
 void TestViewModel::journalAccess()
 {
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
 
     // test failure handling for invalid journal
     QTemporaryFile invalidJournal; // file is surely invalid
@@ -39,7 +39,7 @@ void TestViewModel::rowAccess()
 {
     // used unfiltered journal and check first two lines
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
     QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
     QVERIFY(model.rowCount() > 0);
 
@@ -76,7 +76,7 @@ void TestViewModel::rowAccess()
 void TestViewModel::bootFilter()
 {
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
     QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
 
     // select only second boot
@@ -110,7 +110,7 @@ void TestViewModel::bootFilter()
 void TestViewModel::unitFilter()
 {
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
     QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
 
     // select single service
@@ -145,7 +145,7 @@ void TestViewModel::showKernelMessages()
     const QString arbitraryKernelMessage = "brcmfmac: brcmf_fw_alloc_request: using brcm/brcmfmac43455-sdio for chip BCM4345/6";
 
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
     QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
 
     // check that not contains Kernel message
@@ -178,7 +178,7 @@ void TestViewModel::showKernelMessages()
 void TestViewModel::closestIndexForDateComputation()
 {
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
     QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
 
     QDateTime firstLogEntryDateTime = model.data(model.index(0, 0), JournaldViewModel::DATETIME).toDateTime();
@@ -201,7 +201,7 @@ void TestViewModel::closestIndexForDateComputation()
 void TestViewModel::readFullJournal()
 {
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
     QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
     model.setBootFilter({mBoots.at(0)});
     model.setKernelFilter(true);
@@ -223,7 +223,7 @@ void TestViewModel::readFullJournal()
 void TestViewModel::resetModelHeadAndTailCursorTest()
 {
     JournaldViewModel model;
-    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+    QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
     QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
 
     struct Cursors {
@@ -241,20 +241,27 @@ void TestViewModel::resetModelHeadAndTailCursorTest()
     model.setBootFilter({mBoots.at(0)});
     // boot has 925 non-kernel log entries, fetching once with chunk size 500 gets all
     model.fetchMore(QModelIndex());
+
     // journalctl -b 68f2e61d061247d8a8ba0b8d53a97a52 -D . -o json|head -n1
     QCOMPARE(model.data(model.index(0, 0), JournaldViewModel::CURSOR), cursors.at(0).mHead);
     // journalctl -b 27acae2fe35a40ac93f9c7732c0b8e59 -D . -o json|tail # then look for first message without driver or kernel TRANSPORT
     QCOMPARE(model.data(model.index(model.rowCount() - 1, 0), JournaldViewModel::CURSOR), cursors.at(0).mTail);
+
     // invoke tail seeking
     model.seekTail();
+    model.fetchMore(QModelIndex());
     QCOMPARE(model.data(model.index(0, 0), JournaldViewModel::CURSOR), cursors.at(0).mHead);
     QCOMPARE(model.data(model.index(model.rowCount() - 1, 0), JournaldViewModel::CURSOR), cursors.at(0).mTail);
+
+    // invoke head seeking
     model.seekHead();
+    model.fetchMore(QModelIndex());
     QCOMPARE(model.data(model.index(0, 0), JournaldViewModel::CURSOR), cursors.at(0).mHead);
     QCOMPARE(model.data(model.index(model.rowCount() - 1, 0), JournaldViewModel::CURSOR), cursors.at(0).mTail);
 
     // use model and set boot 1
     model.setBootFilter({mBoots.at(1)});
+    model.fetchMore(QModelIndex());
     // journalctl -b 27acae2fe35a40ac93f9c7732c0b8e59 -D . -o json|head -n1
     QCOMPARE(model.data(model.index(0, 0), JournaldViewModel::CURSOR), cursors.at(1).mHead);
     // journalctl -b 27acae2fe35a40ac93f9c7732c0b8e59 -D . -o json|tail -n1
@@ -262,9 +269,11 @@ void TestViewModel::resetModelHeadAndTailCursorTest()
 
     // invoke tail seeking
     model.seekTail();
+    model.fetchMore(QModelIndex());
     QCOMPARE(model.data(model.index(0, 0), JournaldViewModel::CURSOR), cursors.at(1).mHead);
     QCOMPARE(model.data(model.index(model.rowCount() - 1, 0), JournaldViewModel::CURSOR), cursors.at(1).mTail);
     model.seekHead();
+    model.fetchMore(QModelIndex());
     QCOMPARE(model.data(model.index(0, 0), JournaldViewModel::CURSOR), cursors.at(1).mHead);
     QCOMPARE(model.data(model.index(model.rowCount() - 1, 0), JournaldViewModel::CURSOR), cursors.at(1).mTail);
 }
@@ -299,7 +308,7 @@ void TestViewModel::stringSearch()
     {
         JournaldViewModel model;
         model.setBootFilter({mBoots.at(0)}); // select boot -2 == 68f2e61d061247d8a8ba0b8d53a97a52
-        QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+        QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
         QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
         int foundLine{-1};
         std::vector<int> results;
@@ -318,7 +327,7 @@ void TestViewModel::stringSearch()
         JournaldViewModel model;
         model.setFetchMoreChunkSize(10);
         model.setBootFilter({mBoots.at(0)}); // select boot -2 == 68f2e61d061247d8a8ba0b8d53a97a52
-        QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+        QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
         QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
         int foundLine{-1};
         std::vector<int> results;
@@ -343,8 +352,9 @@ void TestViewModel::stringSearch()
         JournaldViewModel model;
         model.setBootFilter({mBoots.at(0)}); // select boot -2 == 68f2e61d061247d8a8ba0b8d53a97a52
         model.seekTail();
-        QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::Fatal);
+        QAbstractItemModelTester tester(&model, QAbstractItemModelTester::FailureReportingMode::QtTest);
         QCOMPARE(model.setJournaldPath(JOURNAL_LOCATION), true);
+        model.fetchMore(QModelIndex());
         int foundLine = model.rowCount() - 1;
         std::vector<int> results;
         do {
